summaryrefslogtreecommitdiff
path: root/epan/addr_resolv.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2014-04-19 12:29:50 -0700
committerGuy Harris <guy@alum.mit.edu>2014-04-19 19:30:17 +0000
commit97869f2dec0a8cce8ff1745a0bbd747da7a2e1e7 (patch)
treea52e5ae2fe9d04877c951225007f43c145c9ab96 /epan/addr_resolv.h
parentc8f7e16b57ed02dd5b4ccba7ec16ac37ae37beb6 (diff)
downloadwireshark-97869f2dec0a8cce8ff1745a0bbd747da7a2e1e7.tar.gz
More name changes.
Add ep_ to routines that may return ephemeral strings. Change "get_XXX" to "XXX_to_display" if the routine returns a formatted string if it can't get a name. Change-Id: Ia0e82784349752cf4285bf82788316c9588fdd88 Reviewed-on: https://code.wireshark.org/review/1217 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/addr_resolv.h')
-rw-r--r--epan/addr_resolv.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/epan/addr_resolv.h b/epan/addr_resolv.h
index ecd94c61a2..0f92484f5b 100644
--- a/epan/addr_resolv.h
+++ b/epan/addr_resolv.h
@@ -109,28 +109,28 @@ extern gchar *g_pipxnets_path;
/* Functions in addr_resolv.c */
/*
* get_udp_port() returns the port name corresponding to that UDP port,
* or the port number as a string if not found.
*/
-WS_DLL_PUBLIC gchar *get_udp_port(guint port);
+WS_DLL_PUBLIC gchar *ep_udp_port_to_display(guint port);
/*
* get_tcp_port() returns the port name corresponding to that TCP port,
* or the port number as a string if not found.
*/
-WS_DLL_PUBLIC gchar *get_tcp_port(guint port);
+WS_DLL_PUBLIC gchar *ep_tcp_port_to_display(guint port);
/*
* get_dccp_port() returns the port name corresponding to that DCCP port,
* or the port number as a string if not found.
*/
-extern gchar *get_dccp_port(guint port);
+extern gchar *ep_dccp_port_to_display(guint port);
/*
* get_sctp_port() returns the port name corresponding to that SCTP port,
* or the port number as a string if not found.
*/
-WS_DLL_PUBLIC gchar *get_sctp_port(guint port);
+WS_DLL_PUBLIC gchar *ep_sctp_port_to_display(guint port);
/* ep_address_to_display takes as input an "address", as defined in address.h */
/* it returns a string that contains: */
@@ -223,12 +223,12 @@ WS_DLL_PUBLIC const gchar *tvb_get_manuf_name(tvbuff_t *tvb, gint offset);
*/
WS_DLL_PUBLIC const gchar *tvb_get_manuf_name_if_known(tvbuff_t *tvb, gint offset);
/* get_eui64_name returns "<vendor>_%02x:%02x:%02x:%02x:%02x:%02x" if the vendor code is known
"%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x" */
-extern const gchar *get_eui64_name(const guint64 addr);
+extern const gchar *ep_eui64_to_display(const guint64 addr);
-/* get_eui64_name_if_known returns "<vendor>_%02x:%02x:%02x:%02x:%02x:%02x" if the vendor code is known else NULL */
-extern const gchar *get_eui64_name_if_known(const guint64 addr);
+/* ep_eui64_to_display_if_known returns "<vendor>_%02x:%02x:%02x:%02x:%02x:%02x" if the vendor code is known else NULL */
+extern const gchar *ep_eui64_to_display_if_known(const guint64 addr);
/* get_ipxnet_name returns the logical name if found in an ipxnets file,
@@ -109,28 +109,28 @@ extern gchar *g_pipxnets_path;
/* Functions in addr_resolv.c */
/*
- * get_udp_port() returns the port name corresponding to that UDP port,
+ * ep_udp_port_to_display() returns the port name corresponding to that UDP port,
* or the port number as a string if not found.
*/
@@ -109,28 +109,28 @@ extern gchar *g_pipxnets_path;
/*
- * get_tcp_port() returns the port name corresponding to that TCP port,
+ * ep_tcp_port_to_display() returns the port name corresponding to that TCP port,
* or the port number as a string if not found.
*/
@@ -109,28 +109,28 @@ extern gchar *g_pipxnets_path;
/*
- * get_dccp_port() returns the port name corresponding to that DCCP port,
+ * ep_dccp_port_to_display() returns the port name corresponding to that DCCP port,
* or the port number as a string if not found.
*/
@@ -109,28 +109,28 @@ extern gchar *g_pipxnets_path;
/*
- * get_sctp_port() returns the port name corresponding to that SCTP port,
+ * ep_sctp_port_to_display() returns the port name corresponding to that SCTP port,
* or the port number as a string if not found.
*/
@@ -223,12 +223,12 @@ WS_DLL_PUBLIC const gchar *tvb_get_manuf_name(tvbuff_t *tvb, gint offset);
*/
WS_DLL_PUBLIC const gchar *tvb_get_manuf_name_if_known(tvbuff_t *tvb, gint offset);
-/* get_eui64_name returns "<vendor>_%02x:%02x:%02x:%02x:%02x:%02x" if the vendor code is known
+/* ep_eui64_to_display returns "<vendor>_%02x:%02x:%02x:%02x:%02x:%02x" if the vendor code is known
"%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x:%02x" */